==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Të dhëna figure</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Të dhëna elementare</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Hollësi</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Shtojeni në album</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album i ri</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Krejt figurat</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Hap Figurë</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ekportoje</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hiqe nga albumi</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Hiqe si të parapëlqyer</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>E parapëlqyer</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>S’keni leje të shihni figurën</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Lloj</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Datë kur u ndryshua</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Madhësi kartele</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Datë bërjeje</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mënyrë ekspozimi</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program ekspozimi</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Kohëzgjatje ekspozimi</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blic</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Hapje</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Rreze vatrore</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Hapje maksimum</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mënyrë matjeje</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balancë e së bardhës</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Kompensim blici</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model thjerre</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Hapësirë ngjyrash</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamere</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Përmasa</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiketë</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Mbrapsht</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>E mëparshmja</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Pasuesja</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Madhësi 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Sa ta nxërë dritarja</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Përfto tekstin</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rrotulloje në kah kundërorar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rrotulloje në kah orar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Dil nga mënyra “Sa krejt ekrani”</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Sa krejt ekrani</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Shtype</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Shfaqje diapozitivash</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Riemërtojeni</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Shfaq dritare lëvizjesh</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Fshih dritare lëvizjesh</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Vëre si sfond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Shfaqe në përgjegjës kartelash</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Të dhëna figure</translation>
    </message>
    <message>
        <source>day</source>
        <translation>ditë</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Jepni emër të ri</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>E mëparshmja</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pushoje</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Luaje</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Pasuesja</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Dil</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>S’u gjetën kartela figurash</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>S’u gjet kartelë figure</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>S’keni leje të shihni kartelën</translation>
    </message>
</context>
</TS>

==> image-editor_1.0.39.orig.tar.xz: image-editor-1.0.39/libimageviewer/translations/libimageviewer_sq.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sq">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Të dhëna figure</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Të dhëna elementare</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Hollësi</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>Shtojeni në album</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Album i ri</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Krejt figurat</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Hap Figurë</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Ekportoje</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Hiqe nga albumi</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Hiqe si të parapëlqyer</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>E parapëlqyer</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>S’keni leje të shihni figurën</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Emër</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Lloj</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Datë kur u ndryshua</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Madhësi kartele</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Datë bërjeje</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mënyrë ekspozimi</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Program ekspozimi</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Kohëzgjatje ekspozimi</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Blic</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Hapje</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Rreze vatrore</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Hapje maksimum</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mënyrë matjeje</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balancë e së bardhës</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Kompensim blici</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model thjerre</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Hapësirë ngjyrash</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model kamere</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Përmasa</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiketë</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>Mbrapsht</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>E mëparshmja</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Pasuesja</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Madhësi 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Sa ta nxërë dritarja</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Përfto tekstin</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Rrotulloje në kah kundërorar</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Rrotulloje në kah orar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Fshije</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Dil nga mënyra “Sa krejt ekrani”</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Sa krejt ekrani</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Shtype</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Shfaqje diapozitivash</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopjoje</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Riemërtojeni</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Shfaq dritare lëvizjesh</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Fshih dritare lëvizjesh</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Vëre si sfond</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Shfaqe në përgjegjës kartelash</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Të dhëna figure</translation>
    </message>
    <message>
        <source>day</source>
        <translation>ditë</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Ripohojeni</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Jepni emër të ri</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>E mëparshmja</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pushoje</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Luaje</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Pasuesja</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Dil</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>S’u gjetën kartela figurash</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>S’u gjet kartelë figure</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>S’keni leje të shihni kartelën</translation>
    </message>
</context>
</TS>
